@@ -3,6 +3,7 @@ from Cython.Distutils import Extension
 from Cython.Distutils import build_ext
 import os
 import cython_gsl
+import numpy as np
 from glob import glob
 from os.path import splitext
 
@@ -20,10 +21,10 @@ setup(
     name="CythonGSL_examples",
     version="0.2",
     author="Thomas V. Wiecki",
-    author_email="thomas_wiecki@brown.edu",
+    author_email="thomas.wiecki@gmail.com",
     url="http://github.com/twiecki/CythonGSL",
-    description="CythonGSL example integrate.",
-    include_dirs = [cython_gsl.get_include()],
+    description="CythonGSL examples.",
+    include_dirs = [np.get_include(), cython_gsl.get_include()],
     cmdclass = {'build_ext': build_ext},
     classifiers=[
                 'Development Status :: 3 - Alpha',
